@@ -1,4 +1,5 @@
 from enum import Enum
+import uuid
 
 class TWO_FACTOR_AUTH_METHODS(Enum):
     SMS = 0
@@ -23,12 +24,12 @@ API_HEADERS = {
     'phone_model': "Python Api",
     'country': "IT",
     'language': "en",
-    'openudid': "5e4621b0152c0d13",
+    'openudid': '0000'+hex(uuid.getnode())[2:],
     'uid': "",
     'net_type': "wifi",
     'mnc': "02",
     'mcc': "262",
-    'sn': "75814221ee75",
+    'sn': hex(uuid.getnode())[2:],
     'Model_type': "PHONE",
     'timezone': "GMT+01:00",
     'Content-Type': 'application/json'
@@ -96,7 +97,8 @@ class PARAM_TYPE(Enum):
     # PROP_WIFI_MAC             = 'wifi_mac'
     PROP_STATUS             = 'status'
     #
-    BATTERY_LEVEL                   = 1101 #Maybe? 1177
+    BATTERY_LEVEL                   = 1101
+    POWER_MODE                      = 2111
     DEVICE_UPGRADE_NOW              = 1134
     DEVICE_RSSI                     = 1141
     
@@ -127,6 +129,7 @@ class PARAM_TYPE(Enum):
     DOORBELL_RING_RECORD            = 2040
     DOORBELL_AUDIO_RECODE           = 2042
 
+
     WATERMARK_MODE          = 1214              # 1 - hide, 2 - show
     SNOOZE_MODE             = 1271              # The value is base64 encoded
     
@@ -172,4 +175,10 @@ class GUARD_MODE(Enum):
     CUSTOM3     = '5'
     OFF         = '6'
 
-EXCLUDED_ROOT_PROPERTY = ['station_conn', 'member', 'permission', 'params', 'status']
\ No newline at end of file
+EXCLUDED_ROOT_PROPERTY = ['station_conn', 'member', 'permission', 'params', 'status']
+
+class POWER_MODE(Enum):
+#    CHARGING = '0'
+    PLUGGED     = '1'
+    UNPLUGGED   = '2'
+    LINE_MODE   = '3'
\ No newline at end of file
